@@ -57,10 +57,16 @@ cd_util_print_field (const gchar *title, const gchar *message)
 {
 	const guint padding = 15;
 	guint i;
-	guint len;
+	guint len = 0;
 
-	g_print ("%s:", title);
-	len = strlen (title);
+	/* nothing useful to print */
+	if (message == NULL || message[0] == '\0')
+		return;
+
+	if (title != NULL) {
+		g_print ("%s:", title);
+		len = strlen (title) + 1;
+	}
 	for (i = len; i < padding; i++)
 		g_print (" ");
 	g_print ("%s\n", message);
@@ -120,6 +126,12 @@ cd_util_show_profile (CdProfile *profile)
 		 * ColorModel.OutputMode.OutputResolution */
 		cd_util_print_field (_("Format"), tmp);
 	}
+	tmp = cd_profile_get_title (profile);
+	if (tmp != NULL && tmp[0] != '\0') {
+		/* TRANSLATORS: the profile title, e.g.
+		 * "ColorMunki, HP Deskjet d1300 Series" */
+		cd_util_print_field (_("Title"), tmp);
+	}
 	tmp = cd_profile_get_qualifier (profile);
 	if (tmp != NULL && tmp[0] != '\0') {
 		/* TRANSLATORS: the profile qualifier, e.g. RGB.Plain.300dpi */
@@ -183,7 +195,9 @@ cd_util_show_device (CdDevice *device)
 	CdObjectScope scope;
 	CdProfile *profile_tmp;
 	const gchar *tmp;
+	gboolean ret;
 	gchar *str_tmp;
+	GError *error = NULL;
 	GHashTable *metadata;
 	GList *list, *l;
 	GPtrArray *profiles;
@@ -217,6 +231,11 @@ cd_util_show_device (CdDevice *device)
 	cd_util_print_field (_("Vendor"),
 			     cd_device_get_vendor (device));
 
+	/* TRANSLATORS: the device inhibitors */
+	str_tmp = g_strjoinv (", ", (gchar **) cd_device_get_profiling_inhibitors (device));
+	cd_util_print_field (_("Inhibitors"), str_tmp);
+	g_free (str_tmp);
+
 	/* TRANSLATORS: the device serial number */
 	cd_util_print_field (_("Serial"),
 			     cd_device_get_serial (device));
@@ -249,8 +268,19 @@ cd_util_show_device (CdDevice *device)
 		profile_tmp = g_ptr_array_index (profiles, i);
 		/* TRANSLATORS: the profile for the device */
 		str_tmp = g_strdup_printf ("%s %i", _("Profile"), i+1);
-		cd_util_print_field (str_tmp,
-				     cd_profile_get_object_path (profile_tmp));
+		ret = cd_profile_connect_sync (profile_tmp, NULL, &error);
+		if (!ret) {
+			cd_util_print_field (str_tmp,
+					     cd_profile_get_object_path (profile_tmp));
+			cd_util_print_field (NULL,
+					     error->message);
+			g_clear_error (&error);
+		} else {
+			cd_util_print_field (str_tmp,
+					     cd_profile_get_id (profile_tmp));
+			cd_util_print_field (NULL,
+					     cd_profile_get_filename(profile_tmp));
+		}
 		g_free (str_tmp);
 	}
 
