@@ -475,6 +475,8 @@ cd_sensor_cap_to_string (CdSensorCap sensor_cap)
 		return "ambient";
 	if (sensor_cap == CD_SENSOR_CAP_CALIBRATION)
 		return "calibration";
+	if (sensor_cap == CD_SENSOR_CAP_LED)
+		return "led";
 	return "unknown";
 }
 
@@ -503,6 +505,8 @@ cd_sensor_cap_from_string (const gchar *sensor_cap)
 		return CD_SENSOR_CAP_AMBIENT;
 	if (g_strcmp0 (sensor_cap, "calibration") == 0)
 		return CD_SENSOR_CAP_CALIBRATION;
+	if (g_strcmp0 (sensor_cap, "led") == 0)
+		return CD_SENSOR_CAP_LED;
 	return CD_SENSOR_CAP_UNKNOWN;
 }
 
