@@ -26,6 +26,7 @@
 #include <lcms2.h>
 #include <string.h>
 #include <stdlib.h>
+#include <pwd.h>
 
 #include "cd-common.h"
 #include "cd-profile.h"
@@ -59,6 +60,7 @@ struct _CdProfilePrivate
 	gboolean			 is_system_wide;
 	gint64				 created;
 	guint				 owner;
+	GMappedFile			*mapped_file;
 };
 
 enum {
@@ -99,6 +101,16 @@ cd_profile_set_scope (CdProfile *profile, CdObjectScope object_scope)
 	profile->priv->object_scope = object_scope;
 }
 
+/**
+ * cd_profile_get_owner:
+ **/
+guint
+cd_profile_get_owner (CdProfile *profile)
+{
+	g_return_val_if_fail (CD_IS_PROFILE (profile), G_MAXUINT);
+	return profile->priv->owner;
+}
+
 /**
  * cd_profile_set_owner:
  **/
@@ -149,25 +161,50 @@ cd_profile_get_id (CdProfile *profile)
 	return profile->priv->id;
 }
 
+/**
+ * cd_profile_set_object_path:
+ **/
+static void
+cd_profile_set_object_path (CdProfile *profile)
+{
+	gchar *path_tmp;
+	gchar *path_owner;
+	struct passwd *pw;
+
+	/* make sure object path is sane */
+	path_tmp = cd_main_ensure_dbus_path (profile->priv->id);
+
+	/* append the uid to the object path */
+	pw = getpwuid (profile->priv->owner);
+	if (profile->priv->owner == 0 ||
+	    g_strcmp0 (pw->pw_name, DAEMON_USER) == 0) {
+		path_owner = g_strdup (path_tmp);
+	} else {
+		path_owner = g_strdup_printf ("%s_%s",
+					      path_tmp,
+					      pw->pw_name);
+	}
+	profile->priv->object_path = g_build_filename (COLORD_DBUS_PATH,
+						       "profiles",
+						       path_owner,
+						       NULL);
+	g_free (path_owner);
+	g_free (path_tmp);
+}
+
 /**
  * cd_profile_set_id:
  **/
 void
 cd_profile_set_id (CdProfile *profile, const gchar *id)
 {
-	gchar *id_tmp;
-
 	g_return_if_fail (CD_IS_PROFILE (profile));
-	g_free (profile->priv->id);
 
-	/* make sure object path is sane */
-	id_tmp = cd_main_ensure_dbus_path (id);
-	profile->priv->object_path = g_build_filename (COLORD_DBUS_PATH,
-						       "profiles",
-						       id_tmp,
-						       NULL);
+	g_free (profile->priv->id);
 	profile->priv->id = g_strdup (id);
-	g_free (id_tmp);
+
+	/* now calculate this again */
+	cd_profile_set_object_path (profile);
 }
 
 /**
@@ -259,9 +296,10 @@ cd_profile_install_system_wide (CdProfile *profile, GError **error)
 	GError *error_local = NULL;
 	GFile *file_dest = NULL;
 	GFile *file = NULL;
+	CdProfilePrivate *priv = profile->priv;
 
 	/* is icc filename set? */
-	if (profile->priv->filename == NULL) {
+	if (priv->filename == NULL) {
 		ret = FALSE;
 		g_set_error (error,
 			     CD_MAIN_ERROR,
@@ -271,48 +309,73 @@ cd_profile_install_system_wide (CdProfile *profile, GError **error)
 	}
 
 	/* is profile already installed in /var/lib/color */
-	if (g_str_has_prefix (profile->priv->filename,
+	if (g_str_has_prefix (priv->filename,
 			      CD_SYSTEM_PROFILES_DIR)) {
 		ret = FALSE;
 		g_set_error (error,
 			     CD_MAIN_ERROR,
 			     CD_MAIN_ERROR_FAILED,
 			     "file %s already installed in /var",
-			     profile->priv->filename);
+			     priv->filename);
 		goto out;
 	}
 
 	/* is profile already installed in /usr/share/color */
-	if (g_str_has_prefix (profile->priv->filename,
+	if (g_str_has_prefix (priv->filename,
 			      DATADIR "/color")) {
 		ret = FALSE;
 		g_set_error (error,
 			     CD_MAIN_ERROR,
 			     CD_MAIN_ERROR_FAILED,
 			     "file %s already installed in /usr",
-			     profile->priv->filename);
+			     priv->filename);
 		goto out;
 	}
 
 	/* copy */
-	basename = g_path_get_basename (profile->priv->filename);
+	basename = g_path_get_basename (priv->filename);
 	filename = g_build_filename (CD_SYSTEM_PROFILES_DIR,
 				     basename, NULL);
-	file = g_file_new_for_path (profile->priv->filename);
 	file_dest = g_file_new_for_path (filename);
 
-	/* do the copy */
-	ret = g_file_copy (file, file_dest, G_FILE_COPY_OVERWRITE,
-			   NULL, NULL, NULL, &error_local);
-	if (!ret) {
-		ret = FALSE;
-		g_set_error (error,
-			     CD_MAIN_ERROR,
-			     CD_MAIN_ERROR_FAILED,
-			     "failed to copy: %s",
-			     error_local->message);
-		g_error_free (error_local);
-		goto out;
+	/* try to write a mapped file first, else copy the file */
+	if (priv->mapped_file != NULL) {
+		g_debug ("writing mapped file to %s", filename);
+		ret = g_file_replace_contents (file_dest,
+					       g_mapped_file_get_contents (priv->mapped_file),
+					       g_mapped_file_get_length (priv->mapped_file),
+					       NULL,
+					       FALSE,
+					       G_FILE_CREATE_PRIVATE | G_FILE_CREATE_REPLACE_DESTINATION,
+					       NULL,
+					       NULL, /* cancellable */
+					       &error_local);
+		if (!ret) {
+			ret = FALSE;
+			g_set_error (error,
+				     CD_MAIN_ERROR,
+				     CD_MAIN_ERROR_FAILED,
+				     "failed to write mapped file %s: %s",
+				     priv->filename,
+				     error_local->message);
+			g_error_free (error_local);
+			goto out;
+		}
+	} else {
+		file = g_file_new_for_path (priv->filename);
+		ret = g_file_copy (file, file_dest, G_FILE_COPY_OVERWRITE,
+				   NULL, NULL, NULL, &error_local);
+		if (!ret) {
+			ret = FALSE;
+			g_set_error (error,
+				     CD_MAIN_ERROR,
+				     CD_MAIN_ERROR_FAILED,
+				     "failed to copy %s: %s",
+				     priv->filename,
+				     error_local->message);
+			g_error_free (error_local);
+			goto out;
+		}
 	}
 out:
 	g_free (filename);
@@ -673,7 +736,6 @@ static void
 cd_profile_set_metadata_from_profile (CdProfile *profile,
 				      cmsHPROFILE lcms_profile)
 {
-#ifdef HAVE_NEW_LCMS
 	cmsHANDLE dict;
 	const cmsDICTentry* entry;
 	gchar ascii_name[1024];
@@ -703,7 +765,46 @@ cd_profile_set_metadata_from_profile (CdProfile *profile,
 				     g_strdup (ascii_name),
 				     g_strdup (ascii_value));
 	}
-#endif
+}
+
+/**
+ * cd_profile_fixup_title:
+ **/
+static gchar *
+cd_profile_fixup_title (const gchar *text)
+{
+	gchar *title = NULL;
+	gchar *tmp;
+	guint len;
+
+	/* nothing set */
+	if (text == NULL)
+		goto out;
+
+	/* remove the hardcoded confusing title */
+	if (g_str_has_prefix (text, "Default, "))
+		text += 9;
+	title = g_strdup (text);
+
+	/* hack to make old profiles look nice */
+	tmp = g_strstr_len (title, -1, " (201");
+	if (tmp != NULL)
+		*tmp = '\0';
+
+	/* make underscores into spaces */
+	g_strdelimit (title, "_", ' ');
+
+	/* remove any shitty suffix */
+	if (g_str_has_suffix (title, ".icc") ||
+	    g_str_has_suffix (title, ".ICC") ||
+	    g_str_has_suffix (title, ".icm") ||
+	    g_str_has_suffix (title, ".ICM")) {
+		len = strlen (title);
+		if (len > 4)
+			title[len - 4] = '\0';
+	}
+out:
+	return title;
 }
 
 /**
@@ -717,9 +818,7 @@ cd_profile_set_from_profile (CdProfile *profile,
 	cmsColorSpaceSignature color_space;
 	gboolean ret = FALSE;
 	gchar text[1024];
-	guint len;
 	struct tm created;
-	gchar *tmp;
 	const gchar *value;
 	CdProfilePrivate *priv = profile->priv;
 
@@ -728,24 +827,7 @@ cd_profile_set_from_profile (CdProfile *profile,
 				cmsInfoDescription,
 				"en", "US",
 				text, 1024);
-	priv->title = g_strdup (text);
-
-	/* hack to make old profiles look nice */
-	if (priv->title != NULL) {
-		tmp = g_strstr_len (priv->title, -1, " (201");
-		if (tmp != NULL)
-			*tmp = '\0';
-
-		/* remove any shitty prefix */
-		if (g_str_has_suffix (priv->title, ".icc") ||
-		    g_str_has_suffix (priv->title, ".ICC") ||
-		    g_str_has_suffix (priv->title, ".icm") ||
-		    g_str_has_suffix (priv->title, ".ICM")) {
-			len = strlen (priv->title);
-			if (len > 4)
-				priv->title[len - 4] = '\0';
-		}
-	}
+	priv->title = cd_profile_fixup_title (text);
 
 	/* get the profile kind */
 	switch (cmsGetDeviceClass (lcms_profile)) {
@@ -1035,6 +1117,19 @@ cd_profile_set_fd (CdProfile *profile,
 		goto out;
 	}
 
+	/* create a mapped file */
+#if GLIB_CHECK_VERSION(2,31,0)
+	priv->mapped_file = g_mapped_file_new_from_fd (fd, FALSE, error);
+	if (priv->mapped_file == NULL) {
+		g_set_error (error,
+			     CD_MAIN_ERROR,
+			     CD_MAIN_ERROR_FAILED,
+			     "failed to create mapped file from fd %i",
+			     fd);
+		goto out;
+	}
+#endif
+
 	/* parse the ICC file */
 	lcms_profile = cmsOpenProfileFromStream (stream, "r");
 	if (lcms_profile == NULL) {
@@ -1304,6 +1399,8 @@ cd_profile_finalize (GObject *object)
 		g_dbus_connection_unregister_object (priv->connection,
 						     priv->registration_id);
 	}
+	if (priv->mapped_file != NULL)
+		g_mapped_file_unref (priv->mapped_file);
 	g_free (priv->filename);
 	g_free (priv->qualifier);
 	g_free (priv->format);
